#include "tempstream.ih"

TempStream::~TempStream()
{
    unlink(d_filename.c_str());
}
